package logistics.material;

import logistics.quantities.FloatUnit;

/**
 * The MetGallonsKerosene class represents a unit of measurement for kerosene.
 * It is a singleton class, meaning only one instance of the class can exist at a time.
 *
 * @author Nikolaus Köberlein
 * @version 1.0
 */
public class MetGallonsKerosene implements FloatUnit {

    private static MetGallonsKerosene INSTANCE;

    private MetGallonsKerosene() {}

    /**
     * Get the singleton instance of the MetGallonsKerosene class
     *
     * @return The singleton instance of the MetGallonsKerosene class
     */
    public static MetGallonsKerosene getINSTANCE() {
        if (INSTANCE == null) {
            INSTANCE = new MetGallonsKerosene();
        }
        return INSTANCE;
    }

    /**
     * Get a string representation of the MetGallonsKerosene object
     *
     * @return A string representation of the MetGallonsKerosene object
     */
    @Override
    public String toString() {
        return "met gallons of kerosene";
    }
}