package logistics.material;

import logistics.quantities.IntUnit;

/**
 * The Oil class represents a unit of measurement for oil.
 * It is a singleton class, meaning only one instance of the class can exist at a time.
 *
 * @author Nikolaus Köberlein
 * @version 1.0
 */
public class Oil implements IntUnit {

    private static Oil INSTANCE;

    private Oil() {}

    /**
     * Get the singleton instance of the Oil class
     *
     * @return The singleton instance of the Oil class
     */
    public static Oil getINSTANCE() {
        if (INSTANCE == null) {
            INSTANCE = new Oil();
        }
        return INSTANCE;
    }

    /**
     * Get a string representation of the Oil object
     *
     * @return A string representation of the Oil object
     */
    @Override
    public String toString() {
        return "units of oil";
    }
}